class Recipe:
    def __init__(self, title, author, picture_url, total_time, prep_time, cook_time, servings, level, ingredients, directions, categories):
       self.title = title
       self.author = author
       self.picture_url = picture_url
       self.total_time = total_time
       self.prep_time = prep_time
       self.cook_time = cook_time
       self.servings = servings
       self.level = level
       self.ingredients = ingredients
       self.directions = directions
       self.categories = categories



from setuptools import setup

setup(
    name = 'food_network_wrapper',
    packages = ['food_network_wrapper'], 
    version = '0.91',
    description = 'Allows you to easily search and scrape recipes from http://foodnetwork.com',
    author = 'Ben Awad',
    author_email = 'benawad97@gmail.com',
    url = 'https://github.com/benawad/food_network_wrapper', 
    download_url = 'https://github.com/benawad/food_network_wrapper/tarball/0.4',
    keywords = ['cooking', 'recipes', 'recipe', 'python', 'harvest', 'foodnetwork', 'scrape', 'scraping'], 
    install_requires=[
        "beautifulsoup4",
        "lxml",
        "requests",
    ],
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
    ],
)
